==> sprout-spring-boot-autoconfigure-2.2.0.RELEASE-sources.jar: nexcore/sprout/spring/boot/autoconfigure/SproutAutoConfigConst.java <==
package nexcore.sprout.spring.boot.autoconfigure;

public class SproutAutoConfigConst {
	
	/*
	 * Properties Prefix
	*/
	public static final String PREFIX_SPROUT_EVENT_PUBLISHER 				= "sprout.event-publisher";
	public static final String PREFIX_SPROUT_EXCEPTION 						= "sprout.exception";	
	public static final String PREFIX_SPROUT_DATASOURCE 					= "sprout.datasource";
	public static final String PREFIX_SPROUT_DATASOURCE_SQLLOG 				= "sprout.datasource.sqllog";	
	public static final String PREFIX_SPROUT_ACCESS_LOG 					= "sprout.access-log";
	public static final String PREFIX_SPROUT_ERROR_LOG 						= "sprout.error-log";
	public static final String PREFIX_SPROUT_LOG_MONITOR 					= "sprout.log.monitor";
	public static final String PREFIX_SPROUT_RELOAD_MULTICASTER 			= "sprout.reload-multicaster";
	public static final String PREFIX_SPROUT_CODE_DATASOURCE 				= "sprout.code.datasource";
	public static final String PREFIX_SPROUT_CODE_RESOURCE 					= "sprout.code.resource";
	public static final String PREFIX_SPROUT_MESSAGE_DATASOURCE 			= "sprout.message.datasource";
	public static final String PREFIX_SPROUT_MESSAGE_RESOURCE 				= "sprout.message.resource";
	public static final String PREFIX_SPROUT_SECURITY 						= "sprout.security";
	public static final String PREFIX_SPROUT_SECURITY_CORE 					= "sprout.security.core";
	public static final String PREFIX_SPROUT_SECURITY_FILE 					= "sprout.security.file";
	public static final String PREFIX_SPROUT_SECURITY_DB 					= "sprout.security.db";
	public static final String PREFIX_SPROUT_TILES 							= "sprout.tiles";
	public static final String PREFIX_SPROUT_MVC_COMMON_FIELD_SETTER 		= "sprout.mvc.common-field-setter";
	public static final String PREFIX_SPROUT_MVC_DUPLICATE_SUBMIT_PREVENT 	= "sprout.mvc.duplicate-submit-prevent";
	public static final String PREFIX_SPROUT_MVC 							= "sprout.mvc";
	public static final String PREFIX_SPROUT_REDIS 							= "sprout.redis";
	
	/*
	 * Bean Name	
	*/
	public static final String USER_ID_FINDER 							= "userIdFinder";
	public static final String DATASOURCE_INITIALIZER_POST_PROCESSOR 	= "dataSourceInitializerPostProcessor";
	public static final String FRAG_VIEW 								= "fragView";
	public static final String VIEW_RESOLVER 							= "viewResolver";
	public static final String DEFAULT_LOG_DATA_EXTRACTOR 				= "defaultLogDataExtractor";
	public static final String LOGSTASH_ACCESS_LOG_WRITER 				= "logstashAccessLogWriter";
	public static final String DEFAULT_DATASOURCE_NAME 					= "dataSource";
	public static final String DATASOURCE_FOR_SPROUT_NAME 				= "dataSourceForSprout";
	public static final String TRANSACTION_MANAGER_FOR_SPROUT_NAME 		= "transactionManagerForSprout";
	public static final String TRANSACTION_MANAGER_NAME 				= "transactionManager";
	public static final String SYSTEM_DATA_GATHERER_NAME				= "systemDataGatherer";
	public static final String SESSION_COUNT_GATHERER_NAME				= "sessionCountGatherer";
	public static final String SYSTEM_STATUS_LOG_DATA_PROCESSOR_NAME	= "systemStatusLogDataProcessor";
	public static final String SESSION_LISTENER_NAME					= "sessionListener";
	
	/*
	 * Profile	
	*/
	public static final String ACTIVE_PROFILE_NAME_EXCEPTION_RESOLVER_COMPOSITE = "exception-resolver-composite";
	public static final String ACTIVE_PROFILE_NAME_TEST 						= "test";
	public static final String ACTIVE_PROFILE_NAME_DEFAULT						= "default";
	public static final String ACTIVE_PROFILE_NAME_CLOUD						= "cloud";
	public static final String ACTIVE_PROFILE_NAME_PROD							= "prod";
	public static final String ACTIVE_PROFILE_NAME_DEV							= "dev";
	public static final String ACTIVE_PROFILE_NAME_STG							= "stg";
	public static final String[] ACTIVE_PROFILE_NAME_LIST						= { ACTIVE_PROFILE_NAME_PROD
																					,ACTIVE_PROFILE_NAME_DEV
																					,ACTIVE_PROFILE_NAME_STG };
	
	/*
	 * etc
	 */
	public static final String GUID_GENERATE_SERVLET_FILTER 		= "guidGenerateServletFilter";
	public static final String MDC_INSERTING_SERVLET_FILTER 		= "MDCInsertingServletFilter";
	public static final String MYBATIS_AUTO_CONFIGURATION_CLASS 	= "org.mybatis.spring.boot.autoconfigure.MybatisAutoConfiguration";
	public static final String SPRING_ENABLE_WEB_SECURITY_CLASS 	= "org.springframework.security.config.annotation.web.configuration.EnableWebSecurity";
	public static final String APPLICATION_PLAIN 					= "application/plain";
	public static final String REDIS_RELOADMULTICAST_TOPIC 			= "reload";
	public static final String REDIS_RELOADMULTICAST_METHOD_NAME	= "multicastReloadingEvent";
}

==> sprout-spring-boot-autoconfigure-2.3.0.RELEASE-sources.jar: nexcore/sprout/spring/boot/autoconfigure/SproutAutoConfigConst.java <==
package nexcore.sprout.spring.boot.autoconfigure;

public class SproutAutoConfigConst {
	
	/*
	 * Properties Prefix
	*/
	public static final String PREFIX_SPROUT_EVENT_PUBLISHER 				= "sprout.event-publisher";
	public static final String PREFIX_SPROUT_EXCEPTION 						= "sprout.exception";	
	public static final String PREFIX_SPROUT_DATASOURCE 					= "sprout.datasource";
	public static final String PREFIX_SPROUT_DATASOURCE_SQLLOG 				= "sprout.datasource.sqllog";	
	public static final String PREFIX_SPROUT_ACCESS_LOG 					= "sprout.access-log";
	public static final String PREFIX_SPROUT_ERROR_LOG 						= "sprout.error-log";
	public static final String PREFIX_SPROUT_LOG_MONITOR 					= "sprout.log.monitor";
	public static final String PREFIX_SPROUT_RELOAD_MULTICASTER 			= "sprout.reload-multicaster";
	public static final String PREFIX_SPROUT_RELOAD_REDIS 					= "sprout.reload-multicaster.redis";
	public static final String PREFIX_SPROUT_JMX							= "sprout.jmx";
	public static final String PREFIX_SPROUT_CODE_DATASOURCE 				= "sprout.code.datasource";
	public static final String PREFIX_SPROUT_CODE_RESOURCE 					= "sprout.code.resource";
	public static final String PREFIX_SPROUT_MESSAGE_DATASOURCE 			= "sprout.message.datasource";
	public static final String PREFIX_SPROUT_MESSAGE_RESOURCE 				= "sprout.message.resource";
	public static final String PREFIX_SPROUT_SECURITY 						= "sprout.security";
	public static final String PREFIX_SPROUT_SECURITY_CORE 					= "sprout.security.core";
	public static final String PREFIX_SPROUT_SECURITY_FILE 					= "sprout.security.file";
	public static final String PREFIX_SPROUT_SECURITY_DB 					= "sprout.security.db";
	public static final String PREFIX_SPROUT_TILES 							= "sprout.tiles";
	public static final String PREFIX_SPROUT_MVC_COMMON_FIELD_SETTER 		= "sprout.mvc.common-field-setter";
	public static final String PREFIX_SPROUT_MVC_DUPLICATE_SUBMIT_PREVENT 	= "sprout.mvc.duplicate-submit-prevent";
	public static final String PREFIX_SPROUT_MVC 							= "sprout.mvc";
	
	/*
	 * Bean Name	
	*/
	public static final String USER_ID_FINDER 							= "userIdFinder";
	public static final String DATASOURCE_INITIALIZER_POST_PROCESSOR 	= "dataSourceInitializerPostProcessor";
	public static final String FRAG_VIEW 								= "fragView";
	public static final String VIEW_RESOLVER 							= "viewResolver";
	public static final String DEFAULT_LOG_DATA_EXTRACTOR 				= "defaultLogDataExtractor";
	public static final String LOGSTASH_ACCESS_LOG_WRITER 				= "logstashAccessLogWriter";
	public static final String DEFAULT_DATASOURCE_NAME 					= "dataSource";
	public static final String DATASOURCE_FOR_SPROUT_NAME 				= "dataSourceForSprout";
	public static final String TRANSACTION_MANAGER_FOR_SPROUT_NAME 		= "transactionManagerForSprout";
	public static final String TRANSACTION_MANAGER_NAME 				= "transactionManager";
	public static final String SYSTEM_DATA_GATHERER_NAME				= "systemDataGatherer";
	public static final String SESSION_COUNT_GATHERER_NAME				= "sessionCountGatherer";
	public static final String SYSTEM_STATUS_LOG_DATA_PROCESSOR_NAME	= "systemStatusLogDataProcessor";
	public static final String SESSION_LISTENER_NAME					= "sessionListener";
	public static final String EXCIPTION_PROPERTIES_FACTORY_BEAN		= "exceptionPropertiesFactoryBean";
	public static final String MESSAGE_SOURCE							= "messageSource";
	public static final String CODE_SOURCE								= "codeSource";
	
	/*
	 * Profile	
	*/
	public static final String ACTIVE_PROFILE_NAME_EXCEPTION_RESOLVER_COMPOSITE = "exception-resolver-composite";
	public static final String ACTIVE_PROFILE_NAME_TEST 						= "test";

	/*
	 * etc
	 */
	public static final String GUID_GENERATE_SERVLET_FILTER 		= "guidGenerateServletFilter";
	public static final String MDC_INSERTING_SERVLET_FILTER 		= "MDCInsertingServletFilter";
	public static final String MYBATIS_AUTO_CONFIGURATION_CLASS 	= "org.mybatis.spring.boot.autoconfigure.MybatisAutoConfiguration";
	public static final String SPRING_ENABLE_WEB_SECURITY_CLASS 	= "org.springframework.security.config.annotation.web.configuration.EnableWebSecurity";
	public static final String RELOAD_FOR_REDIS_CLASS 				= "nexcore.sprout.spring.boot.autoconfigure.reload.ReloadAutoConfiguration.ReloadForRedis";
	public static final String APPLICATION_PLAIN 					= "application/plain";
	public static final String REDIS_RELOADMULTICAST_TOPIC 			= "ReloadForSprout";
	public static final String REDIS_RELOADMULTICAST_METHOD_NAME	= "multicastReloadingEvent";
	public static final String SPRING_SECURITY_CONTEXT				= "SPRING_SECURITY_CONTEXT";
	public static final String SPRING_APPLICATION_NAME_PROPERTY		= "spring.application.name";
}
